@@ -1,3 +1,7 @@
+import inspect
+import sys
+
+
 class Error(Exception):
     def __init__(self, message, error, internal=True):
         self.message = message
@@ -5,7 +9,7 @@ class Error(Exception):
         self.internal = internal
 
     def __str__(self):
-        return self.error + self.message
+        return self.error_name + self.message
 
 
 class AuthenticationError(Error):
@@ -304,3 +308,17 @@ class NoRowsFoundError(Error):
         self.message = message
         self.error_name = "No Rows Found Error - "
         self.internal = True
+
+
+def external_errors():
+    error_list = []
+    classes = [cls[1] for cls in inspect.getmembers(sys.modules[__name__],
+                                                    lambda member: inspect.isclass(member)
+                                                                   and member.__module__ == __name__)]
+    for error in classes:
+        if error.__name__ == "Error":
+            continue
+        if not error.internal:
+            error_list.append(error.__name__)
+    return error_list
+
